/* eslint-disable jsx-a11y/label-has-associated-control */
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { Button } from '@/shared/Button';
import { Input } from '@/shared/Input';
import React from 'react';
import { currentErrorDataSelector } from '@/redux/modal/modal.selector';

export const ErrorReportModal: React.FC = () => {
  const errorData = useAppSelector(currentErrorDataSelector);

  function getValue(nullableVale: string | null | undefined): string {
    if (!nullableVale) {
      return '';
    }
    return nullableVale;
  }

  const url = getValue(errorData?.url);
  const browser = getValue(errorData?.browser);
  const comment = getValue(errorData?.comment);
  const login = getValue(errorData?.login);
  const email = getValue(errorData?.email);
  const javaStacktrace = getValue(errorData?.javaStacktrace);
  const stacktrace = getValue(errorData?.stacktrace);
  const version = getValue(errorData?.version);
  const message = getValue(errorData?.message);

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const [errorDataToSend, setValue] = React.useState(errorData);

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const handleChange = (e: React.ChangeEvent<HTMLInputElement>): void => {
    const { name, value } = e.target;
    setValue(errorData2 => {
      // eslint-disable-next-line no-console
      console.log(name);
      // eslint-disable-next-line no-console
      console.log(value);

      return errorData2;
    });
  };

  const handleSubmit = async (e: React.FormEvent<HTMLFormElement>): Promise<void> => {
    e.preventDefault();
  };

  return (
    <div className="w-[800px] border border-t-[#E1E0E6] bg-white">
      <form onSubmit={handleSubmit} className="p-4">
        <p className="my-4 font-bold"> {message}</p>
        <p className="my-4">
          If you agree to submit the following information to the minerva maintainers please uncheck
          all boxes that might contain sensitive data.
        </p>
        <label className="mb-1 mt-4 block text-sm">
          <span className="font-semibold">Add comment</span> (max 1000 characters):
        </label>
        <Input type="textarea" value={comment} className="mb-4 text-sm font-medium text-font-400" />
        <div className="grid grid-cols-[15px_743px] gap-2">
          <label className="flex-1 text-sm font-semibold" htmlFor="url">
            <Input
              styleVariant="primaryWithoutFull"
              type="checkbox"
              checked
              className="flex-1 align-bottom text-sm font-semibold"
            />
          </label>
          <label className="block border border-transparent bg-cultured px-2 py-2.5 text-sm font-medium outline-none hover:border-greyscale-600 focus:border-greyscale-600">
            {url}
          </label>
          <label className="block text-sm font-semibold">
            <Input
              styleVariant="primaryWithoutFull"
              type="checkbox"
              checked
              className="flex-1 align-bottom text-sm font-semibold"
            />
          </label>
          <label className="block border border-transparent bg-cultured px-2 py-2.5 text-sm font-medium outline-none hover:border-greyscale-600 focus:border-greyscale-600">
            {browser}
          </label>
          <label className="block text-sm font-semibold">
            <Input
              type="checkbox"
              styleVariant="primaryWithoutFull"
              checked
              className="flex-1 align-bottom text-sm font-semibold"
            />
          </label>
          <label className="block border border-transparent bg-cultured px-2 py-2.5 text-sm font-medium outline-none hover:border-greyscale-600 focus:border-greyscale-600">
            {login} (email: {email})
          </label>
          <label className="block text-sm font-semibold">
            <Input
              styleVariant="primaryWithoutFull"
              type="checkbox"
              checked
              className="flex-1 align-bottom text-sm font-semibold"
            />
          </label>
          <label className="block border border-transparent bg-cultured px-2 py-2.5 text-sm font-medium outline-none hover:border-greyscale-600 focus:border-greyscale-600">
            Minerva {version}
          </label>
        </div>

        <div className="my-4 block max-h-20 overflow-auto border border-transparent bg-cultured px-2 py-2.5 text-sm font-medium outline-none hover:border-greyscale-600 focus:border-greyscale-600">
          Stacktrace:
          <pre>{stacktrace}</pre>
        </div>
        <div className="my-4 block max-h-20 overflow-auto border border-transparent bg-cultured px-2 py-2.5 text-sm font-medium outline-none hover:border-greyscale-600 focus:border-greyscale-600">
          Backend stacktrace:
          <pre>{javaStacktrace}</pre>
        </div>

        <Button type="submit" className="w-full justify-center text-base font-medium">
          Submit
        </Button>
      </form>
    </div>
  );
};
